.. distgen documentation master file, created by
   sphinx-quickstart on Wed Aug 30 11:09:13 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to distgen's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   config
   spec_multispec
   builtins
   macros


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
